<!---
# =================================
# Copyright: CEA-LIST/DIASI/SIALV
# Author : pixano@cea.fr
# License: CECILL-C
# =================================
--->

# Pixano-Inference

## Overview

Pixano-Inference is a Python library that provides an API for performing inference tasks on multi-modal data such as images, videos, and text. It includes model and API providers for various tasks, including mask generation, text-image conditional generation.

Pixano-Inference aims to provide a simple and easy-to-use interface for developers to interact with models solving different tasks and from various providers from a common interface via its RESTful API.

## How to use Pixano-Inference

Please refer to the [Getting Started](./getting_started/index.md) guide for instructions on how to install, configure, and use Pixano-Inference in your project.

For going in-depth on how to use the APIs, please refer to the [API Reference](../api_reference/index.md).

## Contributing

We welcome contributions from the community! Please open issues and pull requests for any bugs or feature requests you may have.

## License

Pixano-Inference is released under the terms of the CeCILL-C license.
